netapp_ontap.models.tape_device_device_names API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.tape_device_device_names`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class TapeDeviceDeviceNamesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the TapeDeviceDeviceNames object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `no_rewind_device: str GET POST PATCH`

    Device name for no rewind.

    Example: nrst6l

  `rewind_device: str GET POST PATCH`

    Device name for rewind.

    Example: rst6l

  `unload_reload_device: str GET POST PATCH`

    Device name for unload or reload operations.

    Example: urst6l